A grid of contour plot(s) of a fitted linear model in 'ggplot2'
Arguments
rsm_model
Model of class "rsm"
formula
A formula, or a list of formulas
decode
This has an effect only if x is an rsm object or other model object that supports coded.data.
In such cases, if decode is TRUE, the coordinate axes are transformed to their decoded values.
n_columns
number of columns for grid layout. Default is 2
text_size
size of text for labelled contour lines. Default is 3
bins
Number of contour bins. Overridden by binwidth
...
Other arguments passed on to contour(). For help with more arguments see ?rsm::contour.lm